// Public domain by Sam Trenholme 2013
//
// This program generates a C-evo map.  This map is based on “Caulixtla”,
// a land form generated by Cephalo’s “Perfect world” map script.
//
// C-evo is a free Civilization2-like game for Windows: http://c-evo.org
//
// “Perfect world” is a map script for Civilization IV:
//
// http://members.socket.net/~ricardo/#Perfect
//
// This takes part of the Caulixtla map (embedded in the source code),
// and randomly converts some forest in to grassland, and some jungle
// in to swamp and grassland.  It then randomly places the dead lands/
// spaceship resources and find places to start the humans and AI
// 
// Once it does that, it outputs a C-evo map file
//
// When called with no arguments, it chooses a random seed from the
// current timestamp:
//
// ./Caulixtla-C-evo.exe will make a file like “time-1367120088.cevo map”
//
// ./Caulixtla-C-evo.exe 1 will make the file “1.cevo map”
//
// It is possible to force where the player will start on the map.  For
// example, the point (47,20) is a nice spot besides a lake.  To force
// that start, try something like
//
// ./Caulixtla-C-evo.exe 1 47 20
//
// If the fifth argument is 'r', more resources are placed around all of the
// human and computer starts
//
// If the fifth argument is 'p', more palm trees are placed in the deserts
//
// Another thing: Random seeds are strings, not numbers

#include <stdint.h>
#include <stdio.h>
#include <stdlib.h>
#include <time.h>
#include <string.h>

// Random number generator http://samiam.org/rg32/
#define rgp uint32_t 
#define rgf(a) for(c=0;c<a;c++){
#define rgn w[c*13]^=s;u[16+c]^=s;
void rgk(rgp*a,rgp*b){rgp m=19,A[19],x,o=13,c,y,r,q[3];rgf(3)y=c*o;q[c
]=b[y+12];for(r=o;--r;)b[y+r]=b[y+r-1];b[y]=q[c];}rgf(12)b[c+1+c%3*o]
^=a[c+1];}rgf(m)r+=c;y=c*7%m;r&=31;x=a[y]^(a[(y+1)%m]|~a[(y+2)%m]);A[
c]=x>>r|x<<(32-r);}rgf(m)a[c]=A[c]^A[(c+1)%m]^A[(c+4)%m];}rgf(3)a[c+o
]^=q[c];}*a^=1;}void rgl(rgp*u,rgp*w,char*v){rgp s,q,c,x;rgf(39)w[c]=
u[c%19]=0;}for(;;rgk(u,w)){rgf(3)for(s=q=0;q<4;){x=*v++;s|=(x?x:1)<<8
*q++;if(!x){rgn;rgf(17)rgk(u,w);}return;}}rgn;}}}rgp rgi(rgp*m,rgp*b)
{static int a=2;a&2?rgk(m,b):0;return m[a^=3];}
uint32_t belt[39], mill[19];

// Initialize the RNG (required)
void rng_init(char *seed) {rgl(mill,belt,seed);}

// Create a random seed based on the time
char *rng_make_seed() {
	char *out;
	out = malloc(100);
	if(out == NULL) {
		return 0;
	}
	snprintf(out,32,"time-%d",time(0));
	return out;
}

// Return a random num between 0 and 65535
uint16_t rgNN(uint16_t n) {
	static uint32_t phase = 0,i;
	if(phase==0) {
		i = rgi(mill,belt);
		phase = 1;
		return i & 0xffff;
	} 
	i >>= 16;
	i &= 0xffff;
	phase = 0;
	return i;
}

// A random int between 0 and n - 1
int32_t rgNum(uint32_t n) {
        uint32_t top, c, z;

        if(n < 1) {
                n = 100;
        } else if(n > 65536) {
                n = 65536;
        }

        top = n * (65536 / n);
        c = top + 1;
        for(z = 0;z < 1000; z++) {
                c = rgNN(0);
                if(c < top) {
                        return c % n;
                }
        }
        return -1;
}


typedef struct {
	uint8_t len;
	uint8_t max;
	uint8_t *x;
	uint8_t *y;
} list;

// Create a new list of tuples
list *list_init(uint8_t max) {
	list *out = 0;
	out = malloc(sizeof(list));
	if(out == NULL) {
		return NULL;
	}
	out->x = malloc(max);
	if(out->x == NULL) {
		free(out);
		return NULL;
	}
	out->y = malloc(max);
	if(out->y == NULL) {
		free(out->x);
		free(out);
		return NULL;
	}
	out->len = 0;
	out->max = max;
	return out;
}

// Destroy a list
void list_zap(list *in) {
	free(in->x);
	free(in->y);
	free(in);
}

// Get element offset from a list
void list_get(list *in, uint8_t offset, uint8_t *x, uint8_t *y) {
	if(in == NULL) {
		*x = 255; *y = 255; return; // ERROR
	}
	if(offset >= in->max || offset >= in->len) {
		*x = 255; *y = 255; return; // ERROR
	}
	*x = in->x[offset];
	*y = in->y[offset];
}

// Add a coordinate pair to the list
int list_append(list *in, uint8_t x, uint8_t y) {
	if(in == NULL) {
		return -1;
	}
	if(in->len + 1 >= in->max) {
		return -1;
	}
	in->x[in->len] = x;
	in->y[in->len] = y;
	in->len++;
	return 1;
}

// Swap two elements in a list
void list_swap(list *in, uint8_t a, uint8_t b) {
	uint8_t t;
	if(in == NULL) {
		return;
	}
	if(a >= in->len || b >= in->len || a == b) {
		return;
	}
	t = in->x[a];
	in->x[a] = in->x[b];
	in->x[b] = t;
	t = in->y[a];
	in->y[a] = in->y[b];
	in->y[b] = t;
}

// Randomly shuffle elements in a list
void list_shuffle(list *in) {
	uint8_t a,b,q;
	if(in == NULL) {
		return;
	}
	if(in->len <= 1) {
		return;
	}
	// I'm pretty sure we only need to run this once to get a random
	// permutation, but since it's O(n), we may as well run it thrice
	for(q=0;q<3;q++) {
		for(a=0;a<in->len - 1;a++) {
			b = rgNum(in->len - a);
			b += a;
			list_swap(in,a,b);
		}
	}
}

// Find a given coordinate in a list.  Return -1 if not found; otherwise
// index with coordinate
int list_find(list *in, uint8_t x, uint8_t y) {
	int a;
	if(in == NULL) {
		return -1;
	}
	for(a=0;a<in->len;a++) {
		if(in->x[a] == x && in->y[a] == y) {
			return a;
		}
	}
	return -1;
}

// Base map of Caulixtla, as generated by Perfect World
uint8_t t[99][99] = {
'*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  
'*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  
'*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  
'*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  
'*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  
'*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  
'*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  
'*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  
'*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  
'*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  
'*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  
'*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  
'*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  
'*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  
'*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  ':' ,  ':' ,  ':' ,  '*' ,  
'*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  
'*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  
'*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  
'*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  
'*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  
'*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  
'*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  
'*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  
'*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  
'*' ,  '*' ,  '*' ,  '*' ,  '*' ,  ':' ,  ':' ,  ':' ,  ':' ,  ':' ,  
'*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  
'*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  
'*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  
'*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  
'*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  
'*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  
'*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  
'*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  
'*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  
'*' ,  '*' ,  '*' ,  '*' ,  ':' ,  ':' ,  ':' ,  ':' ,  ':' ,  ':' ,  
':' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  
'*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  
'*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  
'*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  
'*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  
'*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  
'*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  
'*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  
'*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  
'*' ,  '*' ,  '*' ,  ':' ,  ':' ,  ':' ,  ':' ,  ':' ,  ':' ,  ':' ,  
':' ,  ':' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  
'*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  
'*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  
'*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  
'*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  
'*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  
'*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  
'*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  
'*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  
'*' ,  '*' ,  ':' ,  ':' ,  ':' ,  ':' ,  ':' ,  ':' ,  ':' ,  ':' ,  
':' ,  ':' ,  ':' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  
'*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  
'*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  
'*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  
'*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  
'*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  
'*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  
'*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  
'*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  
'*' ,  ':' ,  ':' ,  ':' ,  ':' ,  ':' ,  ':' ,  ':' ,  ':' ,  ':' ,  
':' ,  ':' ,  ':' ,  ':' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  
'*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  
'*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  
'*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  
'*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  
'*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  
'*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  
'*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  
'*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  
':' ,  ':' ,  ':' ,  ':' ,  ':' ,  ':' ,  ':' ,  ':' ,  ':' ,  ':' ,  
':' ,  ':' ,  ':' ,  ':' ,  ':' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  
'*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  
'*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  
'*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  
'*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  
'*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  
'*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  
'*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  
'*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  ':' ,  
':' ,  ':' ,  ':' ,  ':' ,  ':' ,  ':' ,  ':' ,  ':' ,  ':' ,  ':' ,  
':' ,  ':' ,  ':' ,  ':' ,  ':' ,  ':' ,  '*' ,  '*' ,  '*' ,  '*' ,  
'*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  
'*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  
'*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  
'*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  
'*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  
'*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  
'*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  
'*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  ':' ,  ':' ,  
':' ,  ':' ,  ':' ,  ':' ,  ':' ,  ':' ,  ':' ,  ':' ,  ':' ,  ':' ,  
':' ,  ':' ,  ':' ,  ':' ,  ':' ,  ':' ,  ':' ,  '*' ,  '*' ,  '*' ,  
'*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  
'*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  
'*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  
'*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  
'*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  
'*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  
'*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  
'*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  ':' ,  ':' ,  ':' ,  
':' ,  ':' ,  ':' ,  ':' ,  ':' ,  ':' ,  ':' ,  ':' ,  ':' ,  ':' ,  
':' ,  ':' ,  ':' ,  ':' ,  ':' ,  ':' ,  ':' ,  ':' ,  '*' ,  '*' ,  
'*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  
'*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  
'*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  
'*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  
'*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  
'*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  
'*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  
'*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  ':' ,  ':' ,  ':' ,  ':' ,  
':' ,  ':' ,  ':' ,  ':' ,  ':' ,  ':' ,  ':' ,  ':' ,  ':' ,  ':' ,  
':' ,  ':' ,  ':' ,  ':' ,  ':' ,  ':' ,  ':' ,  ':' ,  ':' ,  '*' ,  
'*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  
'*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  
'*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  
'*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  
'*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  
'*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  
'*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  
'*' ,  '*' ,  '*' ,  '*' ,  '*' ,  ':' ,  ':' ,  ':' ,  ':' ,  ':' ,  
':' ,  ':' ,  ':' ,  ':' ,  ':' ,  ':' ,  ':' ,  ':' ,  ':' ,  ':' ,  
':' ,  ':' ,  ':' ,  ':' ,  ':' ,  ':' ,  ':' ,  ':' ,  ':' ,  ':' ,  
'*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  
'*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  
'*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  
'*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  
'*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  
'*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  
'*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  
'*' ,  '*' ,  '*' ,  '*' ,  ':' ,  ':' ,  ':' ,  ':' ,  ':' ,  ':' ,  
':' ,  ':' ,  ':' ,  ':' ,  ':' ,  ':' ,  ':' ,  ':' ,  ':' ,  ':' ,  
':' ,  ':' ,  ':' ,  ':' ,  ':' ,  ':' ,  ':' ,  ':' ,  ':' ,  ':' ,  
':' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  
'*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  
'*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  
'*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  
'*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  
'*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  
'*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  
'*' ,  '*' ,  '*' ,  ':' ,  ':' ,  ':' ,  ':' ,  ':' ,  ':' ,  ':' ,  
':' ,  ':' ,  ':' ,  ':' ,  ':' ,  ':' ,  ':' ,  ':' ,  ':' ,  ':' ,  
':' ,  ':' ,  ':' ,  ':' ,  ':' ,  ':' ,  ':' ,  ':' ,  ':' ,  ':' ,  
':' ,  ':' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  
'*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  
'*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  
'*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  
'*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  
'*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  
'*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  
'*' ,  '*' ,  ':' ,  ':' ,  ':' ,  ':' ,  ':' ,  ':' ,  ':' ,  ':' ,  
':' ,  ':' ,  ':' ,  ':' ,  ':' ,  ':' ,  ':' ,  ':' ,  ':' ,  ':' ,  
':' ,  ':' ,  ':' ,  ':' ,  ' ' ,  ' ' ,  ' ' ,  ' ' ,  ' ' ,  ':' ,  
':' ,  ':' ,  ':' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  
'*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  
'*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  
'*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  
'*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  
'*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  
'*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  
'*' ,  ':' ,  ':' ,  ':' ,  ':' ,  ':' ,  ':' ,  ':' ,  ':' ,  ':' ,  
':' ,  ' ' ,  ' ' ,  ' ' ,  ':' ,  ':' ,  ':' ,  ':' ,  ':' ,  ':' ,  
':' ,  ':' ,  ' ' ,  ' ' ,  ' ' ,  'f' ,  'h' ,  'm' ,  ' ' ,  ':' ,  
':' ,  ':' ,  ':' ,  ':' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  
'*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  
'*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  
'*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  
'*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  
'*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  
'*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  
':' ,  ':' ,  ':' ,  ':' ,  ':' ,  ' ' ,  ' ' ,  ' ' ,  ' ' ,  ' ' ,  
' ' ,  ' ' ,  'g' ,  ' ' ,  ' ' ,  ' ' ,  ' ' ,  ' ' ,  ' ' ,  ' ' ,  
' ' ,  ' ' ,  ' ' ,  'f' ,  'h' ,  'h' ,  'm' ,  ' ' ,  ' ' ,  ':' ,  
':' ,  ':' ,  ':' ,  ':' ,  ':' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  
'*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  
'*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  
'*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  
'*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  
'*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  
'*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  ':' ,  
':' ,  ':' ,  ' ' ,  ' ' ,  ' ' ,  ' ' ,  'f' ,  ' ' ,  'm' ,  'f' ,  
' ' ,  ' ' ,  'p' ,  'f' ,  'f' ,  'g' ,  'H' ,  'f' ,  'f' ,  'f' ,  
'f' ,  'F' ,  'F' ,  'F' ,  'h' ,  'm' ,  'm' ,  ' ' ,  ':' ,  ':' ,  
':' ,  ':' ,  ':' ,  ':' ,  ':' ,  ':' ,  '*' ,  '*' ,  '*' ,  '*' ,  
'*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  
'*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  
'*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  
'*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  
'*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  
'*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  ':' ,  ':' ,  
' ' ,  ' ' ,  ' ' ,  'f' ,  'f' ,  ' ' ,  ' ' ,  'f' ,  'f' ,  'h' ,  
'F' ,  'f' ,  'p' ,  'h' ,  'h' ,  'g' ,  'F' ,  'f' ,  'h' ,  'g' ,  
'g' ,  'F' ,  'F' ,  'H' ,  'F' ,  'm' ,  ' ' ,  ' ' ,  ':' ,  ':' ,  
':' ,  ':' ,  ':' ,  ':' ,  ':' ,  ':' ,  ':' ,  '*' ,  '*' ,  '*' ,  
'*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  
'*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  
'*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  
'*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  
'*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  
'*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  ':' ,  ':' ,  ':' ,  
' ' ,  'f' ,  'm' ,  ' ' ,  ' ' ,  ' ' ,  'F' ,  'F' ,  'F' ,  'f' ,  
'F' ,  'h' ,  'h' ,  'h' ,  'h' ,  'f' ,  'F' ,  'f' ,  'm' ,  'F' ,  
'H' ,  'f' ,  'G' ,  'f' ,  'f' ,  'm' ,  ' ' ,  ':' ,  ':' ,  ':' ,  
':' ,  ':' ,  ':' ,  ':' ,  ':' ,  ':' ,  ':' ,  ':' ,  '*' ,  '*' ,  
'*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  
'*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  
'*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  
'*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  
'*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  
'*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  ':' ,  ':' ,  ':' ,  ':' ,  
' ' ,  'h' ,  'f' ,  'f' ,  'f' ,  'f' ,  'h' ,  'h' ,  'F' ,  'h' ,  
'F' ,  'h' ,  'h' ,  'h' ,  'p' ,  'f' ,  'g' ,  ' ' ,  'm' ,  'h' ,  
'H' ,  'H' ,  'F' ,  'H' ,  'h' ,  'm' ,  ' ' ,  ':' ,  ':' ,  ':' ,  
':' ,  ':' ,  ':' ,  ':' ,  ':' ,  ':' ,  ':' ,  ':' ,  ':' ,  '*' ,  
'*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  
'*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  
'*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  
'*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  
'*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  
'*' ,  '*' ,  '*' ,  '*' ,  '*' ,  ':' ,  ':' ,  ':' ,  ':' ,  ':' ,  
' ' ,  'h' ,  'f' ,  'g' ,  'h' ,  'h' ,  'h' ,  'h' ,  'F' ,  'F' ,  
'f' ,  'h' ,  'h' ,  'm' ,  'm' ,  'h' ,  'p' ,  ' ' ,  ' ' ,  'h' ,  
'p' ,  'f' ,  'f' ,  'F' ,  'f' ,  'm' ,  ' ' ,  ':' ,  ':' ,  ':' ,  
':' ,  ':' ,  ':' ,  ':' ,  ':' ,  ':' ,  ':' ,  ':' ,  ':' ,  ':' ,  
'*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  
'*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  
'*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  
'*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  
'*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  
'*' ,  '*' ,  '*' ,  '*' ,  ':' ,  ':' ,  ':' ,  ' ' ,  ' ' ,  ' ' ,  
' ' ,  'h' ,  ' ' ,  'f' ,  'h' ,  'h' ,  'h' ,  'h' ,  'h' ,  'G' ,  
'h' ,  'h' ,  'h' ,  'h' ,  'm' ,  'm' ,  'm' ,  'h' ,  ' ' ,  'm' ,  
'p' ,  'p' ,  'd' ,  'F' ,  'p' ,  'm' ,  ' ' ,  ':' ,  ':' ,  ':' ,  
':' ,  ':' ,  ':' ,  ':' ,  ':' ,  ':' ,  ':' ,  ':' ,  ':' ,  ':' ,  
':' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  
'*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  
'*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  
'*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  
'*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  
'*' ,  '*' ,  '*' ,  ':' ,  ' ' ,  ' ' ,  ' ' ,  ' ' ,  'f' ,  ' ' ,  
'f' ,  ' ' ,  ' ' ,  'p' ,  'h' ,  'h' ,  'h' ,  'f' ,  'm' ,  'p' ,  
'p' ,  'h' ,  'd' ,  'd' ,  'h' ,  'h' ,  'm' ,  'm' ,  ' ' ,  'h' ,  
'm' ,  'p' ,  'P' ,  'D' ,  'f' ,  'm' ,  ' ' ,  ' ' ,  ':' ,  ':' ,  
':' ,  ':' ,  ':' ,  ':' ,  ':' ,  ':' ,  ':' ,  ':' ,  ':' ,  ':' ,  
':' ,  ':' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  
'*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  
'*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  
'*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  
'*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  
'*' ,  '*' ,  ':' ,  ':' ,  ' ' ,  'f' ,  'f' ,  ' ' ,  ' ' ,  ' ' ,  
' ' ,  ' ' ,  'f' ,  'f' ,  'h' ,  'h' ,  'h' ,  'p' ,  'm' ,  'p' ,  
'd' ,  'd' ,  'd' ,  'd' ,  'm' ,  'h' ,  'm' ,  ' ' ,  ' ' ,  'm' ,  
'h' ,  'd' ,  'd' ,  'h' ,  'p' ,  'm' ,  'm' ,  ' ' ,  ':' ,  ':' ,  
':' ,  ':' ,  ':' ,  ':' ,  ':' ,  ':' ,  ':' ,  ':' ,  ':' ,  ':' ,  
':' ,  ':' ,  ':' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  
'*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  
'*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  
'*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  
'*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  
'*' ,  ':' ,  ':' ,  ':' ,  ' ' ,  'f' ,  'h' ,  'j' ,  ' ' ,  ' ' ,  
' ' ,  'j' ,  'h' ,  'f' ,  'h' ,  'p' ,  'h' ,  'h' ,  'p' ,  'p' ,  
'd' ,  'd' ,  'm' ,  'd' ,  'h' ,  'm' ,  'h' ,  'd' ,  'M' ,  'h' ,  
'h' ,  'd' ,  'd' ,  'p' ,  'p' ,  'h' ,  'm' ,  ' ' ,  ' ' ,  ':' ,  
':' ,  ':' ,  ':' ,  ':' ,  ':' ,  ':' ,  ':' ,  ':' ,  ':' ,  ':' ,  
':' ,  ':' ,  ':' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  
'*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  
'*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  
'*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  
'*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  
':' ,  ':' ,  ':' ,  ':' ,  ' ' ,  'j' ,  'h' ,  ' ' ,  'j' ,  'j' ,  
'j' ,  'j' ,  'f' ,  'p' ,  'p' ,  'p' ,  'm' ,  'h' ,  'h' ,  'd' ,  
'd' ,  'd' ,  'd' ,  'd' ,  'h' ,  'd' ,  'h' ,  'H' ,  'H' ,  'H' ,  
'H' ,  'd' ,  'd' ,  'p' ,  'h' ,  'f' ,  'm' ,  'm' ,  ' ' ,  ':' ,  
':' ,  ':' ,  ':' ,  ':' ,  ':' ,  ':' ,  ':' ,  ':' ,  ':' ,  ':' ,  
':' ,  ':' ,  ':' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  
'*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  
'*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  
'*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  
'*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  ':' ,  
':' ,  ' ' ,  ' ' ,  ' ' ,  ' ' ,  'h' ,  ' ' ,  ' ' ,  'j' ,  'j' ,  
'j' ,  'j' ,  'f' ,  'f' ,  'f' ,  'f' ,  'd' ,  'd' ,  'h' ,  'h' ,  
'd' ,  'd' ,  'd' ,  'h' ,  'h' ,  'h' ,  'h' ,  'D' ,  'D' ,  'H' ,  
'M' ,  'D' ,  'D' ,  'd' ,  'd' ,  'f' ,  'h' ,  'm' ,  ' ' ,  ' ' ,  
':' ,  ':' ,  ':' ,  ':' ,  ':' ,  ':' ,  ':' ,  ':' ,  ':' ,  ':' ,  
':' ,  ':' ,  ':' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  
'*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  
'*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  
'*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  
'*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  ':' ,  ':' ,  
' ' ,  ' ' ,  'j' ,  ' ' ,  ' ' ,  ' ' ,  ' ' ,  ' ' ,  ' ' ,  ' ' ,  
'j' ,  'J' ,  'F' ,  'G' ,  'g' ,  'p' ,  'p' ,  'p' ,  'p' ,  'p' ,  
'h' ,  'd' ,  'd' ,  'h' ,  'd' ,  'm' ,  'd' ,  'd' ,  'd' ,  'd' ,  
'm' ,  'H' ,  'D' ,  'H' ,  'p' ,  'p' ,  'h' ,  'm' ,  'm' ,  ' ' ,  
':' ,  ':' ,  ':' ,  ':' ,  ':' ,  ':' ,  ':' ,  ':' ,  ':' ,  ':' ,  
':' ,  ':' ,  ':' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  
'*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  
'*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  
'*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  
'*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  ':' ,  ':' ,  ':' ,  
' ' ,  'f' ,  'h' ,  'f' ,  ' ' ,  ':' ,  ':' ,  ':' ,  ':' ,  ' ' ,  
' ' ,  'j' ,  'H' ,  'f' ,  'f' ,  'p' ,  'p' ,  'f' ,  'p' ,  'p' ,  
'd' ,  'd' ,  'd' ,  'h' ,  'd' ,  'h' ,  'd' ,  'd' ,  'h' ,  'd' ,  
'h' ,  'm' ,  'd' ,  'd' ,  'h' ,  'p' ,  'p' ,  'h' ,  'm' ,  ' ' ,  
':' ,  ':' ,  ':' ,  ':' ,  ':' ,  ':' ,  ':' ,  ':' ,  ':' ,  ':' ,  
':' ,  ':' ,  ':' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  
'*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  
'*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  
'*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  
'*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  ':' ,  ':' ,  ':' ,  ':' ,  
' ' ,  ' ' ,  'f' ,  ' ' ,  ' ' ,  ':' ,  ':' ,  ':' ,  ':' ,  ' ' ,  
' ' ,  ' ' ,  ' ' ,  'F' ,  'g' ,  'p' ,  'h' ,  'p' ,  'f' ,  'p' ,  
'p' ,  'h' ,  'd' ,  'd' ,  'd' ,  'd' ,  'h' ,  'd' ,  'd' ,  'd' ,  
'h' ,  'h' ,  'm' ,  'd' ,  'd' ,  'd' ,  'p' ,  'h' ,  'm' ,  ' ' ,  
':' ,  ':' ,  ':' ,  ':' ,  ':' ,  ':' ,  ':' ,  ':' ,  ':' ,  ':' ,  
':' ,  ':' ,  ':' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  
'*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  
'*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  
'*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  
'*' ,  '*' ,  '*' ,  '*' ,  '*' ,  ':' ,  ':' ,  ':' ,  ':' ,  ':' ,  
' ' ,  ' ' ,  ' ' ,  'h' ,  ' ' ,  ':' ,  ':' ,  ' ' ,  ' ' ,  ' ' ,  
'j' ,  'j' ,  ' ' ,  'f' ,  'h' ,  'h' ,  'h' ,  'p' ,  'f' ,  'h' ,  
'h' ,  'h' ,  'd' ,  'd' ,  'd' ,  'd' ,  'd' ,  'd' ,  'd' ,  'h' ,  
'h' ,  'd' ,  'm' ,  'd' ,  'h' ,  'd' ,  'h' ,  'P' ,  'H' ,  ' ' ,  
':' ,  ':' ,  ':' ,  ':' ,  ':' ,  ':' ,  ':' ,  ':' ,  ':' ,  ':' ,  
':' ,  ':' ,  ':' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  
'*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  
'*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  
'*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  
'*' ,  '*' ,  '*' ,  '*' ,  ':' ,  ':' ,  ':' ,  ':' ,  ':' ,  ':' ,  
' ' ,  'f' ,  'f' ,  'm' ,  ' ' ,  ' ' ,  ' ' ,  ' ' ,  'j' ,  'J' ,  
'j' ,  'h' ,  ' ' ,  'h' ,  'h' ,  'h' ,  'f' ,  'p' ,  'g' ,  'p' ,  
'h' ,  'h' ,  'd' ,  'h' ,  'd' ,  'd' ,  'd' ,  'd' ,  'd' ,  'm' ,  
'd' ,  'h' ,  'm' ,  'd' ,  'd' ,  'd' ,  'p' ,  'f' ,  'm' ,  ' ' ,  
':' ,  ':' ,  ':' ,  ':' ,  ':' ,  ':' ,  ':' ,  ':' ,  ':' ,  ':' ,  
':' ,  ':' ,  ':' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  
'*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  
'*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  
'*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  
'*' ,  '*' ,  '*' ,  ':' ,  ':' ,  ':' ,  ':' ,  ':' ,  ':' ,  ':' ,  
' ' ,  'f' ,  'f' ,  'g' ,  'f' ,  ' ' ,  'h' ,  'h' ,  'J' ,  'H' ,  
'h' ,  'h' ,  ' ' ,  'H' ,  'F' ,  'f' ,  'm' ,  'f' ,  'f' ,  'p' ,  
'p' ,  'h' ,  'd' ,  'd' ,  'd' ,  'd' ,  'd' ,  'd' ,  'd' ,  'd' ,  
'd' ,  'm' ,  'm' ,  'd' ,  'd' ,  'd' ,  'd' ,  'h' ,  'm' ,  ' ' ,  
' ' ,  ':' ,  ':' ,  ':' ,  ':' ,  ':' ,  ':' ,  ':' ,  ':' ,  ':' ,  
':' ,  ':' ,  ':' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  
'*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  
'*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  
'*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  
'*' ,  '*' ,  ':' ,  ':' ,  ':' ,  ':' ,  ':' ,  ':' ,  ':' ,  ':' ,  
' ' ,  ' ' ,  ' ' ,  ' ' ,  'f' ,  ' ' ,  'm' ,  'h' ,  'j' ,  'H' ,  
'h' ,  'm' ,  'h' ,  'f' ,  'F' ,  ' ' ,  ' ' ,  'f' ,  ' ' ,  'p' ,  
'p' ,  'p' ,  'd' ,  'd' ,  'd' ,  ' ' ,  ' ' ,  ' ' ,  'd' ,  'd' ,  
'd' ,  'd' ,  'm' ,  'd' ,  'h' ,  'h' ,  'h' ,  'h' ,  'm' ,  'h' ,  
' ' ,  ' ' ,  ':' ,  ':' ,  ':' ,  ':' ,  ':' ,  ':' ,  ':' ,  ':' ,  
':' ,  ':' ,  ':' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  
'*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  
'*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  
'*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  
'*' ,  ':' ,  ':' ,  ':' ,  ':' ,  ':' ,  ':' ,  ':' ,  ':' ,  ':' ,  
':' ,  ':' ,  ':' ,  ' ' ,  ' ' ,  ' ' ,  'm' ,  'h' ,  'H' ,  'M' ,  
'H' ,  'f' ,  'h' ,  'f' ,  'f' ,  ' ' ,  'j' ,  ' ' ,  ' ' ,  ' ' ,  
' ' ,  ' ' ,  ' ' ,  ' ' ,  ' ' ,  ' ' ,  ' ' ,  ' ' ,  'd' ,  'd' ,  
'd' ,  'd' ,  'm' ,  'h' ,  'h' ,  'm' ,  'm' ,  'h' ,  'f' ,  'h' ,  
'H' ,  ' ' ,  ' ' ,  ':' ,  ':' ,  ':' ,  ':' ,  ':' ,  ':' ,  ':' ,  
':' ,  ':' ,  ':' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  
'*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  
'*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  
'*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  
':' ,  ':' ,  ':' ,  ':' ,  ':' ,  ':' ,  ':' ,  ':' ,  ':' ,  ':' ,  
':' ,  ':' ,  ':' ,  ':' ,  ':' ,  ' ' ,  'H' ,  'H' ,  'm' ,  'm' ,  
'h' ,  'F' ,  'F' ,  'F' ,  ' ' ,  ' ' ,  ' ' ,  ' ' ,  ' ' ,  ' ' ,  
' ' ,  ' ' ,  ' ' ,  ' ' ,  ' ' ,  ' ' ,  ' ' ,  ' ' ,  ' ' ,  'd' ,  
'd' ,  ' ' ,  'd' ,  'h' ,  'D' ,  'h' ,  'm' ,  'p' ,  'F' ,  'F' ,  
'h' ,  'h' ,  ' ' ,  ' ' ,  ':' ,  ':' ,  ':' ,  ':' ,  ':' ,  ':' ,  
':' ,  ':' ,  ':' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  
'*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  
'*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  
'*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  ':' ,  
':' ,  ':' ,  ':' ,  ':' ,  ':' ,  ':' ,  ':' ,  ':' ,  ':' ,  ':' ,  
':' ,  ':' ,  ':' ,  ':' ,  ' ' ,  ' ' ,  'j' ,  'g' ,  'f' ,  'f' ,  
'f' ,  'm' ,  'f' ,  'f' ,  'f' ,  'F' ,  'f' ,  'f' ,  'f' ,  'g' ,  
'p' ,  'p' ,  'p' ,  'p' ,  'h' ,  'd' ,  ' ' ,  ' ' ,  ' ' ,  ' ' ,  
'd' ,  ' ' ,  ' ' ,  'd' ,  'D' ,  'd' ,  'm' ,  'h' ,  'm' ,  'f' ,  
'p' ,  'm' ,  'm' ,  ' ' ,  ':' ,  ':' ,  ':' ,  ':' ,  ':' ,  ':' ,  
':' ,  ':' ,  ':' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  
'*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  
'*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  
'*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  ':' ,  ':' ,  
':' ,  ':' ,  ':' ,  ':' ,  ':' ,  ':' ,  ':' ,  ':' ,  ':' ,  ':' ,  
':' ,  ':' ,  ':' ,  ' ' ,  ' ' ,  'J' ,  'H' ,  'f' ,  'm' ,  'M' ,  
'F' ,  'F' ,  'F' ,  'F' ,  'F' ,  'g' ,  'm' ,  'F' ,  'F' ,  'F' ,  
'P' ,  'F' ,  'P' ,  'P' ,  'H' ,  'h' ,  'f' ,  'p' ,  ' ' ,  ' ' ,  
' ' ,  ' ' ,  ' ' ,  'f' ,  'F' ,  'h' ,  'p' ,  'h' ,  'h' ,  'h' ,  
'h' ,  'h' ,  'm' ,  ' ' ,  ':' ,  ':' ,  ':' ,  ':' ,  ':' ,  ':' ,  
':' ,  ':' ,  ':' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  
'*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  
'*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  
'*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  ':' ,  ':' ,  ':' ,  
':' ,  ':' ,  ':' ,  ':' ,  ':' ,  ':' ,  ':' ,  ':' ,  ':' ,  ':' ,  
':' ,  ':' ,  ' ' ,  ' ' ,  'J' ,  'J' ,  'H' ,  'f' ,  'm' ,  'm' ,  
'f' ,  'f' ,  'F' ,  'F' ,  'h' ,  'f' ,  'f' ,  'f' ,  'F' ,  'F' ,  
'F' ,  'F' ,  'F' ,  'h' ,  'm' ,  'j' ,  'j' ,  'j' ,  ' ' ,  ' ' ,  
' ' ,  'g' ,  ' ' ,  'F' ,  'F' ,  'F' ,  'g' ,  'p' ,  'h' ,  'm' ,  
'm' ,  'm' ,  'h' ,  ' ' ,  ':' ,  ':' ,  ':' ,  ':' ,  ':' ,  ':' ,  
':' ,  ':' ,  ':' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  
'*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  
'*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  
'*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  ':' ,  ':' ,  ':' ,  ':' ,  
':' ,  ':' ,  ':' ,  ':' ,  ':' ,  ':' ,  ':' ,  ':' ,  ':' ,  ':' ,  
':' ,  ':' ,  ' ' ,  'J' ,  'J' ,  'j' ,  'j' ,  'f' ,  'f' ,  'F' ,  
'm' ,  'm' ,  'g' ,  'f' ,  'p' ,  'f' ,  'p' ,  'p' ,  'H' ,  'p' ,  
'G' ,  'f' ,  'f' ,  'h' ,  'h' ,  'J' ,  'm' ,  'J' ,  'h' ,  ' ' ,  
'g' ,  'j' ,  'j' ,  'J' ,  'F' ,  'F' ,  'h' ,  'g' ,  'P' ,  'p' ,  
'h' ,  'h' ,  'f' ,  ' ' ,  ':' ,  ':' ,  ':' ,  ':' ,  ':' ,  ':' ,  
':' ,  ':' ,  ':' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  
'*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  
'*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  
'*' ,  '*' ,  '*' ,  '*' ,  '*' ,  ':' ,  ':' ,  ':' ,  ':' ,  ':' ,  
':' ,  ':' ,  ':' ,  ':' ,  ':' ,  ':' ,  ':' ,  ':' ,  ':' ,  ':' ,  
':' ,  ':' ,  ' ' ,  'j' ,  'j' ,  'j' ,  'j' ,  'f' ,  'h' ,  'G' ,  
'm' ,  'm' ,  'f' ,  'p' ,  'p' ,  'f' ,  'P' ,  'F' ,  'M' ,  'G' ,  
'J' ,  'J' ,  'H' ,  'H' ,  'J' ,  'J' ,  'H' ,  'H' ,  'h' ,  ' ' ,  
'h' ,  ' ' ,  'H' ,  'H' ,  'F' ,  'G' ,  'F' ,  'P' ,  'F' ,  'F' ,  
'P' ,  'H' ,  'F' ,  ' ' ,  ':' ,  ':' ,  ':' ,  ':' ,  ':' ,  ':' ,  
':' ,  ':' ,  ':' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  
'*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  
'*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  
'*' ,  '*' ,  '*' ,  '*' ,  ':' ,  ':' ,  ':' ,  ':' ,  ':' ,  ':' ,  
':' ,  ':' ,  ':' ,  ':' ,  ':' ,  ' ' ,  ' ' ,  ' ' ,  ' ' ,  ' ' ,  
' ' ,  ' ' ,  ' ' ,  'J' ,  'J' ,  'J' ,  'M' ,  'J' ,  'f' ,  'G' ,  
'g' ,  'f' ,  'p' ,  'F' ,  'P' ,  'P' ,  'F' ,  'P' ,  'F' ,  'g' ,  
'H' ,  'J' ,  'H' ,  'h' ,  'h' ,  'j' ,  'J' ,  'H' ,  'h' ,  'H' ,  
'h' ,  ' ' ,  'h' ,  'H' ,  'M' ,  'H' ,  'F' ,  'P' ,  'P' ,  'P' ,  
'f' ,  'H' ,  'h' ,  ' ' ,  ':' ,  ':' ,  ':' ,  ':' ,  ':' ,  ':' ,  
':' ,  ':' ,  ':' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  
'*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  
'*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  
'*' ,  '*' ,  '*' ,  ':' ,  ':' ,  ':' ,  ':' ,  ':' ,  ':' ,  ':' ,  
':' ,  ':' ,  ':' ,  ':' ,  ' ' ,  ' ' ,  'j' ,  ' ' ,  'j' ,  'j' ,  
'j' ,  'j' ,  'j' ,  'J' ,  'j' ,  'J' ,  'J' ,  'J' ,  'F' ,  'f' ,  
'M' ,  'h' ,  'h' ,  'f' ,  'h' ,  'h' ,  'p' ,  'm' ,  'H' ,  'h' ,  
'm' ,  'j' ,  'J' ,  'H' ,  'm' ,  'h' ,  'm' ,  'H' ,  'H' ,  'h' ,  
'h' ,  ' ' ,  'm' ,  'f' ,  'h' ,  'h' ,  'h' ,  'h' ,  'P' ,  'p' ,  
'H' ,  'H' ,  'm' ,  ' ' ,  ' ' ,  ':' ,  ':' ,  ':' ,  ':' ,  ':' ,  
':' ,  ':' ,  ':' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  
'*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  
'*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  
'*' ,  '*' ,  '*' ,  '*' ,  ':' ,  ':' ,  ':' ,  ':' ,  ':' ,  ':' ,  
':' ,  ':' ,  ':' ,  ':' ,  ' ' ,  'j' ,  'J' ,  'J' ,  'J' ,  'J' ,  
'h' ,  'j' ,  'J' ,  'J' ,  'J' ,  'J' ,  'J' ,  'j' ,  'j' ,  'f' ,  
'H' ,  'g' ,  'f' ,  'f' ,  'f' ,  'h' ,  'm' ,  'm' ,  ' ' ,  ' ' ,  
' ' ,  ' ' ,  ' ' ,  'H' ,  'H' ,  'H' ,  'm' ,  'h' ,  'h' ,  'h' ,  
'f' ,  ' ' ,  ' ' ,  'f' ,  'f' ,  'f' ,  'p' ,  'p' ,  'M' ,  'p' ,  
'f' ,  'h' ,  'm' ,  'm' ,  ' ' ,  ':' ,  ':' ,  ':' ,  ':' ,  ':' ,  
':' ,  ':' ,  ':' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  
'*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  
'*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  
'*' ,  '*' ,  '*' ,  '*' ,  '*' ,  ':' ,  ':' ,  ':' ,  ':' ,  ':' ,  
':' ,  ':' ,  ':' ,  ':' ,  ' ' ,  'j' ,  'h' ,  'j' ,  'j' ,  'J' ,  
'j' ,  'j' ,  'J' ,  'J' ,  'J' ,  'J' ,  'J' ,  'J' ,  'F' ,  'G' ,  
'F' ,  'F' ,  'f' ,  'm' ,  'f' ,  'm' ,  'm' ,  ' ' ,  ' ' ,  ':' ,  
':' ,  ':' ,  ' ' ,  ' ' ,  'm' ,  'm' ,  'h' ,  'F' ,  'F' ,  ' ' ,  
' ' ,  ' ' ,  'f' ,  'f' ,  'F' ,  'f' ,  'p' ,  'p' ,  'd' ,  'p' ,  
'p' ,  'f' ,  'p' ,  'm' ,  ' ' ,  ' ' ,  ':' ,  ':' ,  ':' ,  ':' ,  
':' ,  ':' ,  ':' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  
'*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  
'*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  
'*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  ':' ,  ':' ,  ':' ,  ':' ,  
':' ,  ':' ,  ':' ,  ':' ,  ' ' ,  'h' ,  'm' ,  'j' ,  'j' ,  'J' ,  
'j' ,  'J' ,  'J' ,  'J' ,  'J' ,  'h' ,  'f' ,  'j' ,  'f' ,  'f' ,  
'p' ,  'P' ,  'p' ,  'f' ,  'f' ,  'm' ,  ' ' ,  ' ' ,  ':' ,  ':' ,  
':' ,  ':' ,  ':' ,  ' ' ,  ' ' ,  'm' ,  'm' ,  'f' ,  'f' ,  'm' ,  
'h' ,  'f' ,  'F' ,  'F' ,  'p' ,  'h' ,  'd' ,  'd' ,  'd' ,  'h' ,  
'd' ,  'p' ,  'p' ,  'm' ,  'm' ,  ' ' ,  ' ' ,  ':' ,  ':' ,  ':' ,  
':' ,  ':' ,  ':' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  
'*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  
'*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  
'*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  ':' ,  ':' ,  ':' ,  
':' ,  ':' ,  ':' ,  ' ' ,  ' ' ,  'h' ,  'h' ,  'j' ,  'J' ,  'J' ,  
'j' ,  'j' ,  'j' ,  'J' ,  'j' ,  'h' ,  'f' ,  'f' ,  'f' ,  'f' ,  
'p' ,  'P' ,  'h' ,  'm' ,  'h' ,  ' ' ,  ' ' ,  ':' ,  ':' ,  ':' ,  
':' ,  ':' ,  ':' ,  ':' ,  ' ' ,  ' ' ,  'm' ,  'm' ,  'f' ,  'F' ,  
'F' ,  'F' ,  'H' ,  'P' ,  'f' ,  'p' ,  'd' ,  'd' ,  'd' ,  'd' ,  
'd' ,  'p' ,  'd' ,  'h' ,  'm' ,  'm' ,  ' ' ,  ' ' ,  ' ' ,  ':' ,  
':' ,  ':' ,  ':' ,  ':' ,  ':' ,  ':' ,  '*' ,  '*' ,  '*' ,  '*' ,  
'*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  
'*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  
'*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  ':' ,  ':' ,  
':' ,  ':' ,  ' ' ,  ' ' ,  'g' ,  'g' ,  'j' ,  'g' ,  'j' ,  'j' ,  
'j' ,  'J' ,  'h' ,  'j' ,  'f' ,  'j' ,  'f' ,  'f' ,  'f' ,  'f' ,  
'm' ,  'P' ,  'h' ,  'm' ,  ' ' ,  ' ' ,  ':' ,  ':' ,  ':' ,  ':' ,  
':' ,  ':' ,  ':' ,  ':' ,  ':' ,  ' ' ,  ' ' ,  'm' ,  'f' ,  'F' ,  
'g' ,  'g' ,  'P' ,  'P' ,  'p' ,  'h' ,  'd' ,  'd' ,  'd' ,  'h' ,  
'h' ,  'd' ,  'd' ,  'd' ,  'h' ,  'm' ,  'm' ,  'm' ,  ' ' ,  ' ' ,  
' ' ,  ' ' ,  ':' ,  ':' ,  ':' ,  ':' ,  '*' ,  '*' ,  '*' ,  '*' ,  
'*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  
'*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  
'*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  ':' ,  
':' ,  ':' ,  ' ' ,  'g' ,  'g' ,  'g' ,  'j' ,  'g' ,  ' ' ,  'j' ,  
'j' ,  'J' ,  'h' ,  'j' ,  'f' ,  'h' ,  'f' ,  'f' ,  'p' ,  'p' ,  
'p' ,  'F' ,  'h' ,  'h' ,  ' ' ,  ':' ,  ':' ,  ':' ,  ':' ,  ':' ,  
':' ,  ':' ,  ':' ,  ':' ,  ':' ,  ':' ,  ' ' ,  'm' ,  'f' ,  'F' ,  
'h' ,  'H' ,  'P' ,  'D' ,  'd' ,  'd' ,  'd' ,  'd' ,  'd' ,  'd' ,  
'd' ,  'd' ,  'h' ,  'd' ,  'd' ,  'd' ,  'p' ,  'm' ,  'm' ,  'h' ,  
'g' ,  ' ' ,  ':' ,  ':' ,  ':' ,  ':' ,  '*' ,  '*' ,  '*' ,  '*' ,  
'*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  
'*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  
'*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  
':' ,  ':' ,  ' ' ,  'j' ,  ' ' ,  'j' ,  ' ' ,  ' ' ,  ' ' ,  ' ' ,  
'j' ,  'J' ,  'h' ,  'j' ,  'j' ,  'g' ,  'F' ,  'f' ,  'p' ,  'p' ,  
'f' ,  'P' ,  'h' ,  'j' ,  ' ' ,  ':' ,  ':' ,  ':' ,  ':' ,  ':' ,  
':' ,  ':' ,  ':' ,  ':' ,  ':' ,  ':' ,  ' ' ,  'm' ,  'H' ,  'F' ,  
'H' ,  'P' ,  'd' ,  'P' ,  'd' ,  'd' ,  'd' ,  'd' ,  'd' ,  'm' ,  
'd' ,  'd' ,  'd' ,  'd' ,  'd' ,  'd' ,  'p' ,  'd' ,  'p' ,  'h' ,  
'h' ,  ' ' ,  ':' ,  ':' ,  ':' ,  ':' ,  '*' ,  '*' ,  '*' ,  '*' ,  
'*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  
'*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  
'*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  
':' ,  ' ' ,  ' ' ,  ' ' ,  ' ' ,  ' ' ,  ' ' ,  ':' ,  ':' ,  ' ' ,  
' ' ,  ' ' ,  'j' ,  'J' ,  'F' ,  'F' ,  'f' ,  'p' ,  'P' ,  'D' ,  
'P' ,  'P' ,  'h' ,  ' ' ,  ' ' ,  ':' ,  ':' ,  ':' ,  ':' ,  ':' ,  
':' ,  ':' ,  ':' ,  ':' ,  ':' ,  ':' ,  ' ' ,  'm' ,  'f' ,  'p' ,  
'H' ,  'D' ,  'D' ,  'D' ,  'd' ,  'd' ,  'd' ,  'h' ,  'h' ,  'd' ,  
'd' ,  'd' ,  'd' ,  'd' ,  'd' ,  'd' ,  'd' ,  'd' ,  'p' ,  'h' ,  
'h' ,  ' ' ,  ':' ,  ':' ,  ':' ,  ':' ,  '*' ,  '*' ,  '*' ,  '*' ,  
'*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  
'*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  
'*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  
':' ,  ' ' ,  'f' ,  ' ' ,  ':' ,  ':' ,  ':' ,  ':' ,  ':' ,  ':' ,  
':' ,  ' ' ,  ' ' ,  'J' ,  'F' ,  'F' ,  'f' ,  'p' ,  'h' ,  'p' ,  
'p' ,  'H' ,  'f' ,  ' ' ,  ':' ,  ':' ,  ':' ,  ':' ,  ':' ,  ':' ,  
':' ,  ':' ,  ':' ,  ':' ,  ':' ,  ':' ,  ' ' ,  'm' ,  'p' ,  'd' ,  
'h' ,  'D' ,  'D' ,  'd' ,  'd' ,  'd' ,  'd' ,  'h' ,  'd' ,  'd' ,  
'd' ,  'd' ,  'd' ,  'd' ,  'd' ,  'd' ,  'd' ,  'd' ,  'p' ,  'h' ,  
'g' ,  ' ' ,  ':' ,  ':' ,  ':' ,  ':' ,  '*' ,  '*' ,  '*' ,  '*' ,  
'*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  
'*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  
'*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  
':' ,  ' ' ,  'g' ,  ' ' ,  ' ' ,  ' ' ,  ':' ,  ':' ,  ':' ,  ':' ,  
':' ,  ':' ,  ' ' ,  'j' ,  'h' ,  'f' ,  'f' ,  'p' ,  'p' ,  'p' ,  
'H' ,  'F' ,  ' ' ,  ' ' ,  ':' ,  ':' ,  ':' ,  ':' ,  ':' ,  ':' ,  
':' ,  ':' ,  ':' ,  ':' ,  ':' ,  ' ' ,  ' ' ,  'm' ,  'p' ,  'd' ,  
'h' ,  'D' ,  'D' ,  'D' ,  'D' ,  'd' ,  'd' ,  'h' ,  'd' ,  'd' ,  
'd' ,  'd' ,  'd' ,  'h' ,  'D' ,  'D' ,  'D' ,  'D' ,  'P' ,  'H' ,  
'F' ,  ' ' ,  ' ' ,  ' ' ,  ' ' ,  ':' ,  ':' ,  ':' ,  ':' ,  ':' ,  
'*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  
'*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  
'*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  ':' ,  
' ' ,  ' ' ,  'f' ,  ' ' ,  'g' ,  ' ' ,  ':' ,  ':' ,  ':' ,  ':' ,  
':' ,  ':' ,  ' ' ,  ' ' ,  'f' ,  'h' ,  'h' ,  'g' ,  'h' ,  'h' ,  
'h' ,  ' ' ,  ' ' ,  ':' ,  ':' ,  ':' ,  ':' ,  ':' ,  ':' ,  ':' ,  
':' ,  ':' ,  ':' ,  ':' ,  ' ' ,  ' ' ,  'm' ,  'h' ,  'p' ,  'p' ,  
'd' ,  'D' ,  'D' ,  'd' ,  'p' ,  'd' ,  ' ' ,  ' ' ,  ' ' ,  'd' ,  
'd' ,  'h' ,  'd' ,  'd' ,  'd' ,  'D' ,  'p' ,  'd' ,  'h' ,  'h' ,  
'h' ,  'j' ,  ' ' ,  'f' ,  ' ' ,  ':' ,  ' ' ,  ' ' ,  ' ' ,  ':' ,  
'*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  
'*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  
'*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  ':' ,  
' ' ,  'f' ,  ' ' ,  'g' ,  'f' ,  ' ' ,  ':' ,  ':' ,  ':' ,  ':' ,  
':' ,  ':' ,  ':' ,  ' ' ,  'f' ,  'h' ,  'h' ,  'm' ,  'h' ,  'h' ,  
'f' ,  ' ' ,  ':' ,  ':' ,  ':' ,  ':' ,  ':' ,  ':' ,  ':' ,  ':' ,  
':' ,  ':' ,  ':' ,  ' ' ,  ' ' ,  'm' ,  'm' ,  'p' ,  'f' ,  'f' ,  
'p' ,  'P' ,  'P' ,  'P' ,  'P' ,  'd' ,  'p' ,  'd' ,  'd' ,  'D' ,  
'h' ,  'p' ,  'p' ,  'd' ,  'p' ,  'H' ,  'p' ,  'p' ,  'h' ,  'h' ,  
'f' ,  ' ' ,  ' ' ,  'f' ,  ' ' ,  ':' ,  ' ' ,  'g' ,  ' ' ,  ':' ,  
'*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  
'*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  
'*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  ':' ,  
' ' ,  ' ' ,  ' ' ,  'p' ,  ' ' ,  ' ' ,  ':' ,  ':' ,  ':' ,  ':' ,  
':' ,  ':' ,  ':' ,  ' ' ,  ' ' ,  'f' ,  'h' ,  'f' ,  ' ' ,  ' ' ,  
' ' ,  ' ' ,  ':' ,  ':' ,  ':' ,  ':' ,  ':' ,  ':' ,  ':' ,  ':' ,  
':' ,  ':' ,  ' ' ,  ' ' ,  'f' ,  'f' ,  'h' ,  'f' ,  'h' ,  'H' ,  
'H' ,  'P' ,  'P' ,  'P' ,  'P' ,  'P' ,  'P' ,  'f' ,  'P' ,  'F' ,  
'f' ,  'f' ,  'h' ,  'p' ,  'm' ,  'P' ,  'f' ,  'h' ,  'h' ,  'h' ,  
' ' ,  ' ' ,  ' ' ,  ' ' ,  ' ' ,  ':' ,  ' ' ,  ' ' ,  ' ' ,  ':' ,  
'*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  
'*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  
'*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  ':' ,  ':' ,  
':' ,  ':' ,  ' ' ,  'g' ,  ' ' ,  ':' ,  ':' ,  ':' ,  ':' ,  ':' ,  
':' ,  ':' ,  ':' ,  ':' ,  ' ' ,  ' ' ,  ' ' ,  ' ' ,  ' ' ,  ':' ,  
':' ,  ':' ,  ':' ,  ':' ,  ':' ,  ':' ,  ':' ,  ':' ,  ':' ,  ':' ,  
':' ,  ':' ,  ' ' ,  'h' ,  ' ' ,  ' ' ,  'H' ,  'g' ,  'g' ,  'g' ,  
'f' ,  'H' ,  'h' ,  'h' ,  'g' ,  'h' ,  'P' ,  'f' ,  'h' ,  'f' ,  
'm' ,  'm' ,  'h' ,  'H' ,  'P' ,  'p' ,  'f' ,  'm' ,  'h' ,  'f' ,  
' ' ,  ':' ,  ':' ,  ':' ,  ':' ,  ':' ,  ':' ,  ':' ,  ':' ,  ':' ,  
'*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  
'*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  
'*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  ':' ,  
':' ,  ':' ,  ' ' ,  ' ' ,  ' ' ,  ':' ,  ':' ,  ':' ,  ':' ,  ':' ,  
':' ,  ':' ,  ':' ,  ':' ,  ':' ,  ':' ,  ':' ,  ':' ,  ':' ,  ':' ,  
':' ,  ':' ,  ':' ,  ':' ,  ':' ,  ':' ,  ':' ,  ':' ,  ':' ,  ':' ,  
':' ,  ':' ,  ' ' ,  ' ' ,  ' ' ,  'f' ,  ' ' ,  'h' ,  'm' ,  'm' ,  
' ' ,  'm' ,  'm' ,  'h' ,  'h' ,  'G' ,  'M' ,  'H' ,  'M' ,  'm' ,  
'f' ,  'g' ,  'f' ,  'f' ,  'h' ,  'h' ,  'h' ,  'm' ,  'f' ,  'f' ,  
' ' ,  ':' ,  ':' ,  ':' ,  ':' ,  ':' ,  '*' ,  '*' ,  '*' ,  '*' ,  
'*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  
'*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  
'*' ,  '*' ,  ':' ,  ':' ,  ':' ,  ':' ,  ':' ,  ':' ,  ':' ,  ':' ,  
':' ,  ':' ,  ':' ,  ':' ,  ':' ,  ':' ,  ':' ,  ':' ,  ':' ,  ':' ,  
':' ,  ':' ,  ':' ,  ':' ,  ':' ,  ':' ,  ':' ,  ':' ,  ':' ,  ':' ,  
':' ,  ':' ,  ':' ,  ':' ,  ':' ,  ':' ,  ':' ,  ':' ,  ':' ,  ':' ,  
':' ,  ':' ,  ':' ,  ':' ,  ' ' ,  ' ' ,  ' ' ,  'g' ,  ' ' ,  ' ' ,  
' ' ,  'f' ,  'h' ,  'm' ,  'm' ,  'h' ,  'm' ,  'f' ,  'f' ,  'm' ,  
'f' ,  'm' ,  'f' ,  'p' ,  'h' ,  'h' ,  'M' ,  'H' ,  ' ' ,  ' ' ,  
' ' ,  ':' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  
'*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  
'*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  
'*' ,  '*' ,  ':' ,  ':' ,  ':' ,  ':' ,  ':' ,  ':' ,  ':' ,  ':' ,  
':' ,  ' ' ,  ' ' ,  ' ' ,  ':' ,  ':' ,  ':' ,  ':' ,  ':' ,  ':' ,  
':' ,  ':' ,  ':' ,  ':' ,  ':' ,  ':' ,  ':' ,  ':' ,  ':' ,  ':' ,  
':' ,  ':' ,  ':' ,  ':' ,  ':' ,  ':' ,  ':' ,  ':' ,  ':' ,  ':' ,  
':' ,  ':' ,  ':' ,  ':' ,  ':' ,  ':' ,  ' ' ,  ' ' ,  ' ' ,  ':' ,  
' ' ,  ' ' ,  'm' ,  'h' ,  'f' ,  ' ' ,  'g' ,  'f' ,  ' ' ,  'm' ,  
'f' ,  'f' ,  'g' ,  'h' ,  'm' ,  'm' ,  'm' ,  'f' ,  ' ' ,  ':' ,  
':' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  
'*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  
'*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  
'*' ,  '*' ,  ':' ,  ' ' ,  ' ' ,  ' ' ,  ':' ,  ':' ,  ':' ,  ':' ,  
':' ,  ' ' ,  'f' ,  ' ' ,  ':' ,  ':' ,  ':' ,  ':' ,  ':' ,  ':' ,  
':' ,  ':' ,  ':' ,  ':' ,  ':' ,  ':' ,  ':' ,  ':' ,  ':' ,  ':' ,  
':' ,  ':' ,  ':' ,  ':' ,  ':' ,  ':' ,  ':' ,  ':' ,  ':' ,  ':' ,  
':' ,  ':' ,  ':' ,  ':' ,  ':' ,  ':' ,  ':' ,  ':' ,  ':' ,  ':' ,  
':' ,  ' ' ,  'm' ,  ' ' ,  ' ' ,  ' ' ,  'f' ,  ' ' ,  ' ' ,  'f' ,  
'f' ,  'f' ,  'h' ,  'm' ,  'm' ,  'm' ,  'f' ,  ' ' ,  ' ' ,  ':' ,  
'*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  
'*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  
'*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  
'*' ,  '*' ,  ':' ,  ' ' ,  'f' ,  ' ' ,  ':' ,  ':' ,  ':' ,  ':' ,  
':' ,  ' ' ,  'f' ,  ' ' ,  ':' ,  ':' ,  ':' ,  ':' ,  ':' ,  ':' ,  
':' ,  ':' ,  ':' ,  ':' ,  ':' ,  ':' ,  ':' ,  ':' ,  ':' ,  ':' ,  
':' ,  ':' ,  ':' ,  ':' ,  ':' ,  ':' ,  ':' ,  ':' ,  ':' ,  ':' ,  
':' ,  ':' ,  ':' ,  ':' ,  ':' ,  ':' ,  ':' ,  ':' ,  ':' ,  ':' ,  
':' ,  ' ' ,  ' ' ,  ' ' ,  ':' ,  ' ' ,  ' ' ,  ' ' ,  ' ' ,  ' ' ,  
' ' ,  ' ' ,  ' ' ,  'f' ,  ' ' ,  'f' ,  ' ' ,  ' ' ,  ':' ,  '*' ,  
'*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  
'*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  
'*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  
'*' ,  '*' ,  ':' ,  ' ' ,  'f' ,  ' ' ,  ':' ,  ':' ,  ':' ,  ':' ,  
':' ,  ' ' ,  ' ' ,  ' ' ,  ':' ,  ':' ,  ':' ,  ':' ,  ':' ,  ':' ,  
':' ,  ':' ,  ':' ,  ':' ,  ':' ,  ':' ,  ':' ,  ':' ,  ':' ,  ':' ,  
':' ,  ':' ,  ':' ,  ':' ,  ':' ,  ':' ,  ':' ,  ':' ,  ':' ,  ':' ,  
':' ,  ':' ,  ':' ,  ':' ,  ':' ,  ':' ,  ':' ,  ':' ,  ':' ,  ':' ,  
':' ,  ':' ,  ':' ,  ':' ,  ':' ,  ':' ,  ':' ,  ':' ,  ':' ,  ':' ,  
':' ,  ':' ,  ' ' ,  ' ' ,  ' ' ,  ' ' ,  ' ' ,  ':' ,  '*' ,  '*' ,  
'*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  
'*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  
'*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  
'*' ,  '*' ,  ':' ,  ' ' ,  ' ' ,  ' ' ,  ':' ,  ':' ,  ':' ,  ':' ,  
':' ,  ':' ,  ':' ,  ':' ,  ':' ,  ':' ,  ':' ,  ':' ,  ':' ,  ':' ,  
':' ,  ':' ,  ':' ,  ':' ,  ':' ,  ':' ,  ':' ,  ':' ,  ':' ,  ':' ,  
':' ,  ' ' ,  ' ' ,  ' ' ,  ':' ,  ':' ,  ':' ,  ':' ,  ':' ,  ':' ,  
':' ,  ':' ,  ':' ,  ':' ,  ':' ,  ':' ,  ':' ,  ':' ,  ':' ,  ':' ,  
':' ,  ':' ,  ':' ,  ':' ,  ':' ,  ':' ,  ':' ,  ':' ,  ':' ,  ':' ,  
':' ,  ':' ,  ':' ,  ':' ,  ':' ,  ':' ,  ':' ,  '*' ,  '*' ,  '*' ,  
'*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  
'*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  
'*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  
'*' ,  '*' ,  ':' ,  ':' ,  ':' ,  ':' ,  ':' ,  ':' ,  ':' ,  ':' ,  
':' ,  ':' ,  ':' ,  ':' ,  ':' ,  ':' ,  ':' ,  ':' ,  ':' ,  ':' ,  
':' ,  ':' ,  ':' ,  ':' ,  ':' ,  ':' ,  ':' ,  ':' ,  ':' ,  ':' ,  
' ' ,  ' ' ,  ' ' ,  ' ' ,  ' ' ,  ':' ,  ':' ,  ':' ,  ':' ,  ':' ,  
':' ,  ':' ,  ':' ,  ':' ,  ':' ,  ':' ,  ':' ,  ':' ,  ':' ,  ':' ,  
':' ,  ':' ,  ':' ,  ':' ,  ':' ,  ':' ,  ':' ,  ':' ,  ':' ,  ':' ,  
':' ,  ':' ,  ':' ,  ':' ,  ':' ,  ':' ,  '*' ,  '*' ,  '*' ,  '*' ,  
'*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  
'*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  
'*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  
'*' ,  '*' ,  ':' ,  ':' ,  ':' ,  ':' ,  ':' ,  ':' ,  ':' ,  ':' ,  
':' ,  ':' ,  ':' ,  ':' ,  ':' ,  ':' ,  ':' ,  ':' ,  ':' ,  ':' ,  
':' ,  ':' ,  ':' ,  ':' ,  ':' ,  ':' ,  ':' ,  ':' ,  ':' ,  ':' ,  
' ' ,  ' ' ,  'f' ,  ' ' ,  ' ' ,  ':' ,  ':' ,  ':' ,  ':' ,  ':' ,  
':' ,  ':' ,  ':' ,  ':' ,  ':' ,  ':' ,  ':' ,  ':' ,  ':' ,  ':' ,  
':' ,  ':' ,  ':' ,  ':' ,  ':' ,  ':' ,  ':' ,  ':' ,  ':' ,  ':' ,  
':' ,  ':' ,  ':' ,  ':' ,  ':' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  
'*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  
'*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  
'*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  
'*' ,  '*' ,  ' ' ,  ' ' ,  ' ' ,  ':' ,  ':' ,  ':' ,  ':' ,  ':' ,  
':' ,  ':' ,  ':' ,  ':' ,  ':' ,  ':' ,  ':' ,  ':' ,  ':' ,  ':' ,  
':' ,  ':' ,  ':' ,  ':' ,  ':' ,  ':' ,  ':' ,  ':' ,  ':' ,  ':' ,  
' ' ,  ' ' ,  'f' ,  ' ' ,  ' ' ,  ':' ,  ':' ,  ':' ,  ':' ,  ':' ,  
':' ,  ':' ,  ':' ,  ':' ,  ':' ,  ':' ,  ':' ,  ':' ,  ':' ,  ':' ,  
':' ,  ':' ,  ':' ,  ':' ,  ':' ,  ':' ,  ':' ,  ':' ,  ':' ,  ':' ,  
':' ,  ':' ,  ':' ,  ':' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  
'*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  
'*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  
'*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  
'*' ,  '*' ,  'f' ,  'f' ,  ' ' ,  ' ' ,  ' ' ,  ':' ,  ':' ,  ':' ,  
':' ,  ':' ,  ':' ,  ':' ,  ':' ,  ':' ,  ':' ,  ':' ,  ':' ,  ':' ,  
':' ,  ':' ,  ':' ,  ':' ,  ':' ,  ':' ,  ':' ,  ':' ,  ':' ,  ':' ,  
' ' ,  ' ' ,  ' ' ,  ' ' ,  ' ' ,  ':' ,  ':' ,  ':' ,  ':' ,  ':' ,  
':' ,  ':' ,  ':' ,  ':' ,  ':' ,  ':' ,  ':' ,  ':' ,  ':' ,  ':' ,  
':' ,  ':' ,  ':' ,  ':' ,  ':' ,  ':' ,  ':' ,  ':' ,  ':' ,  ':' ,  
':' ,  ':' ,  ':' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  
'*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  
'*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  
'*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  
'*' ,  '*' ,  ' ' ,  'f' ,  'f' ,  'f' ,  ' ' ,  ':' ,  ':' ,  ':' ,  
':' ,  ':' ,  ':' ,  ':' ,  ':' ,  ':' ,  ':' ,  ':' ,  ':' ,  ':' ,  
':' ,  ':' ,  ':' ,  ':' ,  ':' ,  ':' ,  ':' ,  ':' ,  ':' ,  ':' ,  
':' ,  ' ' ,  ' ' ,  ' ' ,  ':' ,  ':' ,  ':' ,  ':' ,  ':' ,  ':' ,  
':' ,  ':' ,  ':' ,  ':' ,  ':' ,  ':' ,  ':' ,  ':' ,  ':' ,  ':' ,  
':' ,  ':' ,  ':' ,  ':' ,  ':' ,  ':' ,  ':' ,  ':' ,  ':' ,  ':' ,  
':' ,  ':' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  
'*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  
'*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  
'*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  
'*' ,  '*' ,  ' ' ,  'h' ,  'm' ,  'f' ,  ' ' ,  ':' ,  ':' ,  ':' ,  
':' ,  ':' ,  ':' ,  ':' ,  ':' ,  ':' ,  ':' ,  ':' ,  ':' ,  ':' ,  
':' ,  ':' ,  ':' ,  ':' ,  ':' ,  ':' ,  ':' ,  ':' ,  ':' ,  ':' ,  
':' ,  ':' ,  ':' ,  ':' ,  ':' ,  ':' ,  ':' ,  ':' ,  ':' ,  ':' ,  
':' ,  ':' ,  ':' ,  ':' ,  ':' ,  ':' ,  ':' ,  ':' ,  ':' ,  ':' ,  
':' ,  ':' ,  ':' ,  ':' ,  ':' ,  ':' ,  ':' ,  ':' ,  ':' ,  ':' ,  
':' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  
'*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  
'*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  
'*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  
'*' ,  '*' ,  ' ' ,  'f' ,  'f' ,  ' ' ,  ' ' ,  ':' ,  ':' ,  ':' ,  
':' ,  ':' ,  ':' ,  ':' ,  ':' ,  ':' ,  ':' ,  ':' ,  ':' ,  ':' ,  
':' ,  ':' ,  ':' ,  ':' ,  ':' ,  ':' ,  ':' ,  ':' ,  ':' ,  ':' ,  
':' ,  ':' ,  ':' ,  ':' ,  ':' ,  ':' ,  ':' ,  ':' ,  ':' ,  ':' ,  
':' ,  ':' ,  ':' ,  ':' ,  ':' ,  ':' ,  ':' ,  ':' ,  ':' ,  ':' ,  
':' ,  ':' ,  ':' ,  ':' ,  ':' ,  ':' ,  ':' ,  ':' ,  ':' ,  ':' ,  
'*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  
'*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  
'*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  
'*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  
'*' ,  '*' ,  ' ' ,  ' ' ,  ' ' ,  ' ' ,  ':' ,  ':' ,  ':' ,  ':' ,  
':' ,  ':' ,  ':' ,  ':' ,  ':' ,  ':' ,  ':' ,  ':' ,  ':' ,  ':' ,  
':' ,  ':' ,  ':' ,  ':' ,  ':' ,  ':' ,  ':' ,  ':' ,  ':' ,  ':' ,  
':' ,  ':' ,  ':' ,  ':' ,  ':' ,  ':' ,  ':' ,  ':' ,  ':' ,  ':' ,  
':' ,  ':' ,  ':' ,  ':' ,  ':' ,  ':' ,  ':' ,  ':' ,  ':' ,  ':' ,  
':' ,  ':' ,  ':' ,  ':' ,  ':' ,  ':' ,  ':' ,  ':' ,  ':' ,  '*' ,  
'*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  
'*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  
'*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  
'*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  
'*' ,  '*' ,  ':' ,  ':' ,  ':' ,  ':' ,  ':' ,  ':' ,  ':' ,  ':' ,  
':' ,  ':' ,  ':' ,  ':' ,  ':' ,  ':' ,  ':' ,  ':' ,  ':' ,  ':' ,  
':' ,  ':' ,  ':' ,  ':' ,  ':' ,  ':' ,  ':' ,  ':' ,  ':' ,  ':' ,  
':' ,  ':' ,  ':' ,  ':' ,  ':' ,  ':' ,  ':' ,  ':' ,  ':' ,  ':' ,  
':' ,  ':' ,  ':' ,  ':' ,  ':' ,  ':' ,  ':' ,  ':' ,  ':' ,  ':' ,  
':' ,  ':' ,  ':' ,  ':' ,  ':' ,  ':' ,  ':' ,  ':' ,  '*' ,  '*' ,  
'*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  
'*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  
'*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  
'*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  
'*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  
'*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  
'*' ,  '*' ,  '*' ,  '*' ,  '*' ,  ':' ,  ':' ,  ':' ,  ':' ,  ':' ,  
':' ,  ':' ,  ':' ,  ':' ,  ':' ,  ':' ,  ':' ,  ':' ,  ':' ,  ':' ,  
':' ,  ':' ,  ':' ,  ':' ,  ':' ,  ':' ,  ':' ,  ':' ,  ':' ,  ':' ,  
':' ,  ':' ,  ':' ,  ':' ,  ':' ,  ':' ,  ':' ,  '*' ,  '*' ,  '*' ,  
'*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  
'*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  
'*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  
'*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  
'*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  
'*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  
'*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  ':' ,  ':' ,  ':' ,  ':' ,  
':' ,  ':' ,  ':' ,  ':' ,  ':' ,  ':' ,  ':' ,  ':' ,  ':' ,  ':' ,  
':' ,  ':' ,  ':' ,  ':' ,  ':' ,  ':' ,  ':' ,  ':' ,  ':' ,  ':' ,  
':' ,  ':' ,  ':' ,  ':' ,  ':' ,  ':' ,  '*' ,  '*' ,  '*' ,  '*' ,  
'*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  
'*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  
'*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  
'*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  
'*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  
'*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  
'*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  ':' ,  ':' ,  ':' ,  
':' ,  ':' ,  ':' ,  ':' ,  ':' ,  ':' ,  ':' ,  ':' ,  ':' ,  ':' ,  
':' ,  ':' ,  ':' ,  ':' ,  ':' ,  ':' ,  ':' ,  ':' ,  ':' ,  ':' ,  
':' ,  ':' ,  ':' ,  ':' ,  ':' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  
'*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  
'*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  
'*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  
'*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  
'*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  
'*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  
'*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  ':' ,  ':' ,  
':' ,  ':' ,  ':' ,  ':' ,  ':' ,  ':' ,  ':' ,  ':' ,  ':' ,  ':' ,  
':' ,  ':' ,  ':' ,  ':' ,  ':' ,  ':' ,  ':' ,  ':' ,  ':' ,  ':' ,  
':' ,  ':' ,  ':' ,  ':' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  
'*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  
'*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  
'*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  
'*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  
'*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  
'*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  
'*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  ':' ,  
':' ,  ':' ,  ':' ,  ':' ,  ':' ,  ':' ,  ':' ,  ':' ,  ':' ,  ':' ,  
':' ,  ':' ,  ':' ,  ':' ,  ':' ,  ':' ,  ':' ,  ':' ,  ':' ,  ':' ,  
':' ,  ':' ,  ':' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  
'*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  
'*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  
'*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  
'*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  
'*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  
'*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  
'*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  
':' ,  ':' ,  ':' ,  ':' ,  ':' ,  ':' ,  ':' ,  ':' ,  ':' ,  ':' ,  
':' ,  ':' ,  ':' ,  ':' ,  ':' ,  ':' ,  ':' ,  ':' ,  ':' ,  ':' ,  
':' ,  ':' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  
'*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  
'*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  
'*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  
'*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  
'*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  
'*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  
'*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  
'*' ,  ':' ,  ':' ,  ':' ,  ':' ,  ':' ,  ':' ,  ':' ,  ':' ,  ':' ,  
':' ,  ':' ,  ':' ,  ':' ,  ':' ,  ':' ,  ':' ,  ':' ,  ':' ,  ':' ,  
':' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  
'*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  
'*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  
'*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  
'*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  
'*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  
'*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  
'*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  
'*' ,  '*' ,  ':' ,  ':' ,  ':' ,  ':' ,  ':' ,  ':' ,  ':' ,  ':' ,  
':' ,  ':' ,  ':' ,  ':' ,  ':' ,  ':' ,  ':' ,  ':' ,  ':' ,  ':' ,  
'*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  
'*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  
'*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  
'*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  
'*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  
'*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  
'*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  
'*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  
'*' ,  '*' ,  '*' ,  ':' ,  ':' ,  ':' ,  ':' ,  ':' ,  ':' ,  ':' ,  
':' ,  ':' ,  ':' ,  ':' ,  ':' ,  ':' ,  ':' ,  ':' ,  ':' ,  '*' ,  
'*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  
'*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  
'*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  
'*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  
'*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  
'*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  
'*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  
'*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  
'*' ,  '*' ,  '*' ,  '*' ,  ':' ,  ':' ,  ':' ,  ':' ,  ':' ,  ':' ,  
':' ,  ':' ,  ':' ,  ':' ,  ':' ,  ':' ,  ':' ,  ':' ,  '*' ,  '*' ,  
'*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  
'*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  
'*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  
'*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  
'*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  
'*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  
'*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  
'*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  
'*' ,  '*' ,  '*' ,  '*' ,  '*' ,  ':' ,  ':' ,  ':' ,  ':' ,  ':' ,  
':' ,  ':' ,  ':' ,  ':' ,  ':' ,  ':' ,  ':' ,  '*' ,  '*' ,  '*' ,  
'*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  
'*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  
'*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  
'*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  
'*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  
'*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  
'*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  
'*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  
'*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  ':' ,  ':' ,  ':' ,  ':' ,  
':' ,  ':' ,  ':' ,  ':' ,  ':' ,  ':' ,  '*' ,  '*' ,  '*' ,  '*' ,  
'*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  
'*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  
'*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  
'*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  
'*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  
'*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  
'*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  
'*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  
'*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  ':' ,  ':' ,  ':' ,  
':' ,  ':' ,  ':' ,  ':' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  
'*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  
'*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  
'*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  
'*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  
'*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  
'*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  
'*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  
'*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  
'*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  ':' ,  ':' ,  
':' ,  ':' ,  ':' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  
'*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  
'*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  
'*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  
'*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  
'*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  
'*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  
'*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  
'*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  
'*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  ':' ,  
':' ,  ':' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  
'*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  
'*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  
'*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  
'*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  
'*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  
'*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  
'*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  
'*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  
'*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  
'*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  
'*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  
'*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  
'*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  
'*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  
'*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  
'*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  
'*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  
'*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  
'*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  
'*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  
'*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  
'*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  
'*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  
'*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  
'*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  
'*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  
'*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  
'*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  
'*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  
'*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  
'*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  
'*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  
'*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  
'*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  
'*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  
'*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  
'*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  
'*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  
'*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  
'*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  
'*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  
'*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  
'*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  
'*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  
'*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  
'*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  
'*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  
'*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  
'*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  
'*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  
'*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  
'*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  
'*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  
'*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  
'*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  
'*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  
'*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  
'*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  
'*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  
'*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  
'*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  
'*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  
'*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  
'*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  
'*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  
'*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  
'*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  
'*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  
'*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  
'*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  
'*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  
'*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  
'*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  
'*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  
'*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  
'*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  
'*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  
'*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  
'*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  
'*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  
'*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  
'*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  
'*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  
'*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  
'*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  
'*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  
'*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  
'*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  
'*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  
'*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  
'*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  
'*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  
'*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  
'*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  
'*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' ,  '*' };

// Output map of Caulixtla
uint8_t z[99][99];
// Bonus  map of Caulixtla
uint8_t b[99][99];
list *hstarts = 0, *cstarts = 0, *desert = 0;

// Generate the map; this takes the base map in "t" and copies it to
// "z", randomly adding more grassland to make the map more playable in
// C-evo.  Also notes desert squares where we may build the spaceship
// and fills "b" with random percentage numbers (numbers from 0 to 99)
void gen_map() {
	uint8_t x, y, r, a, c, q;
	int32_t ox, oy;
	if(desert != 0)  {list_zap(desert);}
	desert = list_init(250);

	for(y=0;y<99;y++) {
		for(x=0;x<83;x++) {
			b[y][x] = rgNum(100);
			z[y][x] = t[y][x];
			// Randomly convert 30% of jungle in to grassland
			// 10% in to swamp
			if((z[y][x] & 0xdf) == 'J') {
				r = rgNum(10);
				if(r < 3) {	
					if(z[y][x] == 'J') {
						z[y][x] = 'G';
					} else {
						z[y][x] = 'g';
					}
				} else if (r == 3) {
					if(z[y][x] == 'J') {
						z[y][x] = 'S';
					} else {
						z[y][x] = 's';
					}
				}
			}			
			// Randomly convert 35% of forest in to grassland
			if((z[y][x] & 0xdf) == 'F') {
				r = rgNum(20);
				if(r < 7) {
					if(z[y][x] == 'F') {
						z[y][x] = 'G';
					} else {
						z[y][x] = 'g';
					}
				}	
			}
			// Convert ocean near coast in to coastland
			if(t[y][x] == ':' || t[y][x] == '*') {
				z[y][x] = ':';
				ox = x - 2;
				oy = y - 2;
				for(a=0;a<5;a++) {
					for(c=0;c<5;c++) {
						if(ox+c >= 0 && ox+c <= 99 &&
						   oy+a >= 0 && oy+a <= 99) {
							q = t[oy+a][ox+c];
						} else {
							q = ':';
						}
						if(q != '*' && q != ':' && 
						   q != ' ' && 
						   !(a == 0 && c == 0) &&
						   !(a == 4 && c == 0) &&
						   !(a == 0 && c == 4) &&
						   !(a == 4 && c == 4)) {
							z[y][x] = ' ';
						}
					}
				}
			}

			// Some desert tiles will have spaceship resources
			// or deadlands (197 total desert tiles)
			if(z[y][x] == 'd' && b[y][x] > 50) {
				list_append(desert,x,y);
			}
		}
	}
}

// Find the player and AI starts on the map
// Affects the gloabl variables hstarts and cstarts
void gen_starts() {
	list *shash[99];
	int a, c, x, y, ox, oy, q, r;
	int smax = 0, score = 0, good = 0;

	if(hstarts != 0) {list_zap(hstarts);}
	hstarts = list_init(250);
	if(cstarts != 0) {list_zap(cstarts);}
	cstarts = list_init(250);
	for(a=0;a<99;a++) {
		shash[a] = list_init(100);
	}	

	// Find good places to start players
	for(y=0;y<92;y++) {
		for(x=0;x<81;x++) {
			ox = x - 2;
			oy = y - 2;
			score = 0;
			for(a=0;a<5;a++) {
				for(c=0;c<5;c++) {
					if(ox+c >= 0 && ox+c <= 99 &&
					   oy+a >= 0 && oy+a <= 99) {
						q = z[oy+a][ox+c];
						r = b[oy+a][ox+c];
					} else {
						q = ':';
						r = 100;
					}
					if('q' >= 'A' && q <= 'Z') {
						q += 32;
					}
					if(!(a == 0 && c == 0) &&
					   !(a == 4 && c == 0) &&
					   !(a == 0 && c == 4) &&
					   !(a == 4 && c == 4)) {
						if(r>3 && r<=10 && 
						 (q=='p' || q==' ' || q=='f'
						  || q=='j' || q=='d')) {
							score += 3;
						} else if(q == 'g') {
							score += 2;
						} else if(q == 'p') {
							score += 1;	
						}
					}
				}
			}
			q = z[y][x];
			if(q != 'g' && q != 'p' && q != 'h') {
				score = 0;
			}
			if(score > 3) {
				list_append(shash[score],x,y);
			}
			if(score > smax) {
				smax = score;
			}
		}
	}
	list_shuffle(shash[smax]);

	// We give the humans the best starts
	for(a=0;a<shash[smax]->len;a++) {
		good = 1;
		x = shash[smax]->x[a];		
		y = shash[smax]->y[a];		
		for(c=0;c<hstarts->len;c++) {
			ox = hstarts->x[c];	
			oy = hstarts->y[c];	
			// Starts need to be 20 squares from each other
			if((x - ox) * (x - ox) + (y - oy) * (y - oy) < 400) {
				good = 0;
			}
		}	
		if(good == 1) {
			list_append(hstarts,x,y);
		}
	}

	// We give the AIs other starts
	while((hstarts->len + cstarts->len < 7)	&& smax > 3) {
		smax--;
		list_shuffle(shash[smax]);
		for(a = 0; a < shash[smax]->len; a++) {
			good = 1;
			x = shash[smax]->x[a];
			y = shash[smax]->y[a];
			for(c = 0; c < hstarts->len; c++) {
				ox = hstarts->x[c];	
				oy = hstarts->y[c];
				// Computer starts: 20 squares from humans
				if((x - ox) * (x - ox) + (y - oy) * (y - oy) 
				   < 400) {
					good = 0;
				}
			}
			for(c = 0; c < cstarts->len; c++) {
				ox = cstarts->x[c];	
				oy = cstarts->y[c];
				// Computer starts: 12 squares from each other
				if((x - ox) * (x - ox) + (y - oy) * (y - oy) 
				   < 144) {
					good = 0;
				}
			}
			if(good == 1) {
				list_append(cstarts,x,y);
			}
		}
	}
	// No memory leak!
	for(a=0;a<99;a++) {list_zap(shash[a]);}
}

// Show the first “w” columns of the map.  Make “w” 100 to show the
// entire map; outputs on standard output
void show_map(int w) {
	int x, y;
	for(y = 0; y < 97; y++) {
		for(x = 0; x < w; x++) {
			printf("%c",z[y][x]);
		}
		printf("\n");
	}
}

// Show the contents of a list on standard output
void show_list(list *in) {
	int a;
	if(in == 0) {
		printf("NULL\n");
		return;
	}
	printf("%d of %d: ",in->len,in->max);
	for(a=0;a<in->len;a++) {
		printf("(%d, %d) ",in->x[a],in->y[a]);
		if(a % 7 == 6) {
			printf("\n");
		}
	}
	printf("\n");
}

// Calculate a single C-evo map point
uint32_t cmap(int square,int bonus,int hs,int cs,int ds,int palms) {
	uint32_t mask = 0;
	int nobonus;
	if(square >= 'A' && square <= 'Z') {
		square += 32; // lower-case
		mask |= 0x80; // River
	}
	if(square == ':') {
		nobonus = 1; // Never any bonus
	} else if(square == 'g' || square == 'a') {
		nobonus = 2; // No trade bonus
	} else {
		nobonus = 0; // All possible bonuses
	}
	if(bonus <= 3 && nobonus == 0) {
		mask |= 0x40; // Trade bonus
	} else if(square == 'd' && bonus <= palms) {
		mask |= 0x20; // Palm tree
	} else if(bonus <= 10 && nobonus != 1) { 
		mask |= 0x20; // Food bonus
	}
	// Dead lands / spaceship resources
	if(ds == 1 || ds == 2) {
		mask = 0x03000000;
	} else if(ds == 3 || ds == 4) {
		mask = 0x05000000;
	} else if(ds == 5 || ds == 6) {
		mask = 0x07000000;
	} else if(ds > 6 && ds <= 12) {
		mask = 0x01000000; // Deadlands w/o space resources
	}
	// Starts
	if(hs != 0) {
		mask = 0x00200000;
	} else if(cs != 0) {
		mask = 0x00400000;
	}

	switch(square) {
		case ':':
			return mask;
		case ' ':
			return mask | 0x01;
		case 'g':
			return mask | 0x02;
		case 'd':
			return mask | 0x03;
		case 'p':
			return mask | 0x04;
		case 't':
			return mask | 0x05;
		case 'a':
			return mask | 0x06;
		case 's': 
			return mask | 0x07;
		case 'f':
			return mask | 0x09;
		case 'j': // Jungle tiles are just forest at mid latitudes
			return mask | 0x09;
		case 'h':
			return mask | 0x0a;
		case 'm':
			return mask | 0x0b;
	}
	return mask; // Default to ocean
}
				
// Draw a single C-evo map point
void out_cmap(FILE *out,int square,int bonus,int hs,int cs,int ds,int palms) {
	uint32_t o = 0;
	int a;
	o = cmap(square,bonus,hs,cs,ds,palms);
	for(a=0;a<4;a++) {
		putc(o & 0xff,out);
		o >>= 8;
	}
}

// Output a 32-bit little-endian number in to the file out
void out_num(FILE *out, uint32_t o) {
	int a;
	for(a=0;a<4;a++) {
		putc(o & 0xff,out);
		o >>= 8;
	}
}

// C-evo’s map header
void out_map_header(FILE *out, int sizex, int sizey) {
	fputs("cEvoMap",out); fputc(0,out); // Magic number/header
	out_num(out,0); // Format (0)
	out_num(out,0); // MaxTurn (0)
	out_num(out,sizex);
	out_num(out,sizey);
}

// Increase the resources around a single point on the map 
void more_resources(int x, int y) {
	int a,c;
	if(x < 2 || x > 96 || y < 2 || y > 96) {
		return; // Too close to edge
	}
	a = x - 2;
	for(;a <= x + 2;a++) {
		c = y - 2;
		for(;c <= y + 2;c++) {
			if((a == x - 2 || a == x + 2) && 
					(c == y - 2 || c == y + 2)) {
				continue;
			} else {	
				b[c][a] >>= 2; // 4x resources
			}
		}
	}
}
			
			
// Draw a single horizontal line in the C-evo map, which is a diagonal
// ray in the input map
void show_cevo_ray(int ix, int iy, int sizex, FILE *out, int palms) {
	int a, c, square, bonus, hs, cs, ds, di;
	for(a=0;a<sizex;a++) {
		// What is on this sqaure?
		if(ix >= 0 && iy >= 0 && ix < 90 && iy < 91) {
			square = z[iy][ix];
			bonus = b[iy][ix];
		} else {
			square = ':';
			bonus = 100;
		}
		if(square == 0) {
			square = ':';
			bonus = 100;
		}
		// Is this square a human start?
		hs = 0;
		for(c=0;c<hstarts->len;c++) {
			if(hstarts->x[c]==ix && hstarts->y[c]==iy) {
				hs = 1;
				break;
			}
		}
		// Is this square an AI (computer) start?
		cs = 0;
		for(c=0;c<cstarts->len;c++) {
			if(cstarts->x[c]==ix && cstarts->y[c]==iy) {
				cs = 1;
				break;
			}
		}
		// Is this square a desert square with deadlands/startship
		// resources?
		ds = 0;
		di = 0;
		for(c=0;c<desert->len;c++) {
			di++;
			if(desert->x[c]==ix && desert->y[c]==iy) {
				ds = di;
			}
		}
		
		out_cmap(out,square,bonus,hs,cs,ds,palms);
		ix++;
		iy--;
	}
}
		
// Show the C-evo map file to out
void show_cevo_map(FILE *out, int palm_resources) {
	int nwx = -16, nwy = 60, sizex = 72, sizey = 96;
	int ix, iy, a;

	ix = nwx;	
	iy = nwy;
	out_map_header(out,sizex,sizey);
	for(a=0;a<sizey;a+=2) {
		show_cevo_ray(ix,iy,sizex,out,palm_resources);
		ix++;
		show_cevo_ray(ix,iy,sizex,out,palm_resources);		
		iy++;
	}
}
		
main(int argc, char **argv) {
	char *seed;
	char *d;
	int a, q;
	int fx = -1, fy = -1; // Force a player start to be a certain point
	int good;
	int extra_resources = 0;
	int palm_resources = 10;
	FILE *o;
	if(argc == 1) {
		seed = rng_make_seed();
	} else if(argc == 2) {
		seed = argv[1];
	} else if(argc == 4) {
		seed = argv[1];
		fx = atoi(argv[2]);
		fy = atoi(argv[3]);
	} else if(argc == 5 && *(argv[4]) == 'r') {
		seed = argv[1];
		fx = atoi(argv[2]);
		fy = atoi(argv[3]);
		extra_resources = 1;
	} else if(argc == 5 && *(argv[4]) == 'p') {
		seed = argv[1];
		fx = atoi(argv[2]);
		fy = atoi(argv[3]);
		palm_resources = 17; // More palm trees
	} else {
		printf("Usage: Caulixtla-C-evo {seed} {startx} {starty}\n");
		printf("Example: Caulixtla-C-evo 1234 47 20\n");
		return 1;
	}
	d = seed;
	for(a=0;a<32;a++) {
		if(*d == 0) {
			break;
		} else if(*d == '/' || *d == ':') {
			*d = '_';	
		}
		if(a==31) {
			*d = 0;
		}
		d++;
	}
	rng_init(seed);
	d = malloc(a + 32);
	if(d == 0) {
		return 2;
	}
	strncpy(d,seed,a + 1);	
	strncat(d,".cevo map",12);
	hstarts = list_init(250);
	cstarts = list_init(250);
	good = 0;
	a = 0;
	while(good == 0 && a < 100000) {
		gen_map();
		gen_starts();
		if(hstarts->len >= 2 && (hstarts->len + cstarts->len) >= 7) {
			good = 1;
		}
		if(fx != -1) {
			q = t[fy][fx];
			if(list_find(hstarts,fx,fy) == -1) {
				good = 0;
			}
			if(q >= 'A' && q <= 'Z') {q+=32;} // Lower case
			if(q == ' ' || q == 'm' || q == 'd' || q == ':') {
				good = 1;
				printf("Not possible to put player there, "
					"ignoring\n");
			}
		}
		if(a % 200 == 199) {
			printf("Try %d...\n",a + 1);
			fflush(stdout); // Windows needs this
		}
		a++;
	}
	if(a>=99999) {
		printf("Fatal: No map made\n");
		return 3;
	}
	list_shuffle(desert);
	if(extra_resources != 0) {
		for(a = 0; a < hstarts->len; a++) {
			more_resources(hstarts->x[a],hstarts->y[a]);
		}	
		for(a = 0; a < cstarts->len; a++) {
			more_resources(cstarts->x[a],cstarts->y[a]);
		}	
	}
	o = fopen(d,"wb");
	if(o == NULL) {
		o = stdout;
	}
	show_cevo_map(o,palm_resources);
	if(o != stdout) {
		printf("%s written\n",d);
	}
	return 0;
}

